@@ -2,7 +2,7 @@ from loguru import logger
 from argparse import ArgumentParser
 
 from rsack.version import __version__
-from rsack import bugs, genie, qobuz
+from rsack import bugs, genie
 from rsack.utils import bugs_id, genie_id, Settings
 
 def get_args():
@@ -11,7 +11,6 @@ def get_args():
     parser.add_argument('-v', '--version', action='store_true', dest='version', required=False)
     parser.add_argument('-b', '--bugs', action='store_true', dest="bugs", required=False)
     parser.add_argument('-g', '--genie', action='store_true', dest="genie", required=False)
-    parser.add_argument('-q', '--qobuz', action='store_true', dest="qobuz", required=False)
     parser.add_argument('-u', '--url', nargs='*', dest="url", required=False)
     parser.add_argument('-cfg', '--config', action='store_true', dest="config", required=False)
     parser.add_argument('-o', '--open', action='store_true', dest="open", required=False)
@@ -43,7 +42,4 @@ def main():
                 type = "album"
             else: # Catch invalid info types
                 logger.critical("URL type unkown")
-            genie.Download(type=type, id=int(match.group(2)))
-    elif args.qobuz:
-        for url in args.url:
-            qobuz.Download(url)
\ No newline at end of file
+            genie.Download(type=type, id=int(match.group(2)))
\ No newline at end of file
